@@ -41,6 +41,8 @@ class Settings:
     mypy_args: list[str] = field(default_factory=list)
     format: Literal["text", "github", None] | None = None
     sort_by: Literal["filename", "error"] | None = None
+    verbose: bool = False
+    timing_stats: Path | None = None
 
     def __post_init__(self) -> None:
         if self.enable_all and self.disable_all:
@@ -81,6 +83,8 @@ class Settings:
             mypy_args=new.mypy_args or old.mypy_args,
             format=new.format or old.format,
             sort_by=new.sort_by or old.sort_by,
+            verbose=old.verbose or new.verbose,
+            timing_stats=old.timing_stats or new.timing_stats,
         )
 
     def get_python_version(self) -> tuple[int, int]:
@@ -237,13 +241,10 @@ def parse_config_file(contents: str) -> Settings:
 
 
 def parse_command_line_args(args: list[str]) -> Settings:
-    if not args or args[0] in ("--help", "-h"):
+    if not args:
         return Settings(help=True)
 
-    if args[0] in ("--version", "-v"):
-        return Settings(version=True)
-
-    if args[0] == "gen":
+    if len(args) == 1 and args[0] == "gen":
         return Settings(generate=True)
 
     iargs = iter(args)
@@ -260,6 +261,12 @@ def parse_command_line_args(args: list[str]) -> Settings:
         if arg == "--debug":
             settings.debug = True
 
+        elif arg in ("--help", "-h"):
+            settings.help = True
+
+        elif arg in ("--version", "-v"):
+            settings.version = True
+
         elif arg == "--quiet":
             settings.quiet = True
 
@@ -314,15 +321,29 @@ def parse_command_line_args(args: list[str]) -> Settings:
         elif arg == "--sort":
             settings.sort_by = validate_sort_by(get_next_arg(arg, iargs))
 
+        elif arg == "--verbose":
+            settings.verbose = True
+
+        elif arg == "--timing-stats":
+            settings.timing_stats = Path(get_next_arg(arg, iargs))
+
         elif arg == "--":
             settings.mypy_args = list(iargs)
 
         elif arg.startswith("-"):
             raise ValueError(f'refurb: unsupported option "{arg}"')
 
-        else:
+        elif arg:
             settings.files.append(arg)
 
+        else:
+            raise ValueError("refurb: argument cannot be empty")
+
+    if len(args) > 1 and (settings.help or settings.version):
+        msg = f"refurb: unexpected value before/after `{args[0]}`"
+
+        raise ValueError(msg)
+
     return settings
 
 
@@ -331,8 +352,16 @@ def load_settings(args: list[str]) -> Settings:
 
     file = Path(cli_args.config_file or "pyproject.toml")
 
-    config_file = (
-        parse_config_file(file.read_text()) if file.exists() else Settings()
-    )
+    try:
+        config_file = parse_config_file(file.read_text())
+
+    except IsADirectoryError as ex:
+        raise ValueError(f'refurb: "{file}" is a directory') from ex
+
+    except FileNotFoundError as ex:
+        if cli_args.config_file:
+            raise ValueError(f'refurb: "{file}" was not found') from ex
+
+        config_file = Settings()  # pragma: no cover
 
     return Settings.merge(config_file, cli_args)
